Module: PaperTrail::VersionConcern::ClassMethods
- Defined in:
- lib/paper_trail/version_concern.rb
Overview
:nodoc:
Instance Method Summary collapse
- #between(start_time, end_time) ⇒ Object
- #creates ⇒ Object
- #destroys ⇒ Object
- #item_subtype_column_present? ⇒ Boolean
- #not_creates ⇒ Object
-
#object_changes_col_is_json? ⇒ Boolean
Returns whether the
object_changescolumn is using thejsontype supported by PostgreSQL. -
#object_col_is_json? ⇒ Boolean
Returns whether the
objectcolumn is using thejsontype supported by PostgreSQL. -
#preceding(obj, timestamp_arg = false) ⇒ Object
Returns versions before
obj. - #primary_key_is_int? ⇒ Boolean
-
#subsequent(obj, timestamp_arg = false) ⇒ Object
Returns versions after
obj. -
#timestamp_sort_order(direction = "asc") ⇒ Object
Defaults to using the primary key as the secondary sort order if possible.
- #updates ⇒ Object
-
#where_object(args = {}) ⇒ Object
Given a hash of attributes like ‘name: ’Joan’‘, query the
versions.objectscolumn. -
#where_object_changes(args = {}) ⇒ Object
Given a hash of attributes like ‘name: ’Joan’‘, query the
versions.objects_changescolumn. - #with_item_keys(item_type, item_id) ⇒ Object
Instance Method Details
#between(start_time, end_time) ⇒ Object
52 53 54 55 56 57 |
# File 'lib/paper_trail/version_concern.rb', line 52 def between(start_time, end_time) where( arel_table[:created_at].gt(start_time). and(arel_table[:created_at].lt(end_time)) ).order() end |
#creates ⇒ Object
36 37 38 |
# File 'lib/paper_trail/version_concern.rb', line 36 def creates where event: "create" end |
#destroys ⇒ Object
44 45 46 |
# File 'lib/paper_trail/version_concern.rb', line 44 def destroys where event: "destroy" end |
#item_subtype_column_present? ⇒ Boolean
28 29 30 |
# File 'lib/paper_trail/version_concern.rb', line 28 def item_subtype_column_present? column_names.include?("item_subtype") end |
#not_creates ⇒ Object
48 49 50 |
# File 'lib/paper_trail/version_concern.rb', line 48 def not_creates where "event <> ?", "create" end |
#object_changes_col_is_json? ⇒ Boolean
Returns whether the object_changes column is using the json type supported by PostgreSQL.
137 138 139 |
# File 'lib/paper_trail/version_concern.rb', line 137 def object_changes_col_is_json? i[json jsonb].include?(columns_hash["object_changes"].try(:type)) end |
#object_col_is_json? ⇒ Boolean
Returns whether the object column is using the json type supported by PostgreSQL.
131 132 133 |
# File 'lib/paper_trail/version_concern.rb', line 131 def object_col_is_json? i[json jsonb].include?(columns_hash["object"].type) end |
#preceding(obj, timestamp_arg = false) ⇒ Object
Returns versions before obj.
rubocop:disable Style/OptionalBooleanParameter
149 150 151 152 153 154 155 |
# File 'lib/paper_trail/version_concern.rb', line 149 def preceding(obj, = false) if != true && primary_key_is_int? preceding_by_id(obj) else (obj) end end |
#primary_key_is_int? ⇒ Boolean
123 124 125 126 127 |
# File 'lib/paper_trail/version_concern.rb', line 123 def primary_key_is_int? @primary_key_is_int ||= columns_hash[primary_key].type == :integer rescue StandardError # TODO: Rescue something more specific true end |
#subsequent(obj, timestamp_arg = false) ⇒ Object
Returns versions after obj.
rubocop:disable Style/OptionalBooleanParameter
166 167 168 169 170 171 172 |
# File 'lib/paper_trail/version_concern.rb', line 166 def subsequent(obj, = false) if != true && primary_key_is_int? subsequent_by_id(obj) else (obj) end end |
#timestamp_sort_order(direction = "asc") ⇒ Object
Defaults to using the primary key as the secondary sort order if possible.
61 62 63 64 65 |
# File 'lib/paper_trail/version_concern.rb', line 61 def (direction = "asc") [arel_table[:created_at].send(direction.downcase)].tap do |array| array << arel_table[primary_key].send(direction.downcase) if primary_key_is_int? end end |
#updates ⇒ Object
40 41 42 |
# File 'lib/paper_trail/version_concern.rb', line 40 def updates where event: "update" end |
#where_object(args = {}) ⇒ Object
Given a hash of attributes like ‘name: ’Joan’‘, query the versions.objects column.
“‘ SELECT “versions”.* FROM “versions” WHERE (“versions”.“object” LIKE ’% name: Joan %‘) “`
This is useful for finding versions where a given attribute had a given value. Imagine, in the example above, that Joan had changed her name and we wanted to find the versions before that change.
Based on the data type of the object column, the appropriate SQL operator is used. For example, a text column will use like, and a jsonb column will use ‘@>`.
87 88 89 90 |
# File 'lib/paper_trail/version_concern.rb', line 87 def where_object(args = {}) raise ArgumentError, "expected to receive a Hash" unless args.is_a?(Hash) Queries::Versions::WhereObject.new(self, args).execute end |
#where_object_changes(args = {}) ⇒ Object
Given a hash of attributes like ‘name: ’Joan’‘, query the versions.objects_changes column.
“‘ SELECT “versions”.* FROM “versions” WHERE .. (“versions”.“object_changes” LIKE ’% name:
-
Joan
%‘ OR “versions”.“object_changes” LIKE ’% name: -%
-
Joan
%‘) “`
This is useful for finding versions immediately before and after a given attribute had a given value. Imagine, in the example above, that someone changed their name to Joan and we wanted to find the versions immediately before and after that change.
Based on the data type of the object column, the appropriate SQL operator is used. For example, a text column will use like, and a jsonb column will use ‘@>`.
118 119 120 121 |
# File 'lib/paper_trail/version_concern.rb', line 118 def where_object_changes(args = {}) raise ArgumentError, "expected to receive a Hash" unless args.is_a?(Hash) Queries::Versions::WhereObjectChanges.new(self, args).execute end |
#with_item_keys(item_type, item_id) ⇒ Object
32 33 34 |
# File 'lib/paper_trail/version_concern.rb', line 32 def with_item_keys(item_type, item_id) where item_type: item_type, item_id: item_id end |