Class: PaperTrail::ModelConfig
- Inherits:
-
Object
- Object
- PaperTrail::ModelConfig
- Defined in:
- lib/paper_trail/model_config.rb
Overview
Configures an ActiveRecord model, mostly at application boot time, but also sometimes mid-request, with methods like enable/disable.
Constant Summary collapse
- E_CANNOT_RECORD_AFTER_DESTROY =
<<-STR.strip_heredoc.freeze paper_trail.on_destroy(:after) is incompatible with ActiveRecord's belongs_to_required_by_default. Use on_destroy(:before) or disable belongs_to_required_by_default. STR
- E_HPT_ABSTRACT_CLASS =
<<~STR.squish.freeze An application model (%s) has been configured to use PaperTrail (via `has_paper_trail`), but the version model it has been told to use (%s) is an `abstract_class`. This could happen when an advanced feature called Custom Version Classes (http://bit.ly/2G4ch0G) is misconfigured. When all version classes are custom, PaperTrail::Version is configured to be an `abstract_class`. This is fine, but all application models must be configured to use concrete (not abstract) version models. STR
Instance Method Summary collapse
-
#initialize(model_class) ⇒ ModelConfig
constructor
A new instance of ModelConfig.
-
#on_create ⇒ Object
Adds a callback that records a version after a “create” event.
-
#on_destroy(recording_order = "before") ⇒ Object
Adds a callback that records a version before or after a “destroy” event.
-
#on_touch ⇒ Object
Adds a callback that records a version after a “touch” event.
-
#on_update ⇒ Object
Adds a callback that records a version after an “update” event.
-
#setup(options = {}) ⇒ Object
private
Set up ‘@model_class` for PaperTrail.
- #version_class ⇒ Object
Constructor Details
#initialize(model_class) ⇒ ModelConfig
Returns a new instance of ModelConfig.
22 23 24 |
# File 'lib/paper_trail/model_config.rb', line 22 def initialize(model_class) @model_class = model_class end |
Instance Method Details
#on_create ⇒ Object
Adds a callback that records a version after a “create” event.
29 30 31 32 33 34 35 |
# File 'lib/paper_trail/model_config.rb', line 29 def on_create @model_class.after_create { |r| r.paper_trail.record_create if r.paper_trail.save_version? } return if @model_class.[:on].include?(:create) @model_class.[:on] << :create end |
#on_destroy(recording_order = "before") ⇒ Object
Adds a callback that records a version before or after a “destroy” event.
40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/paper_trail/model_config.rb', line 40 def on_destroy(recording_order = "before") unless %w[after before].include?(recording_order.to_s) raise ArgumentError, 'recording order can only be "after" or "before"' end if recording_order.to_s == "after" && cannot_record_after_destroy? raise E_CANNOT_RECORD_AFTER_DESTROY end @model_class.send( "#{recording_order}_destroy", lambda do |r| return unless r.paper_trail.save_version? r.paper_trail.record_destroy(recording_order) end ) return if @model_class.[:on].include?(:destroy) @model_class.[:on] << :destroy end |
#on_touch ⇒ Object
Adds a callback that records a version after a “touch” event.
86 87 88 89 90 91 92 93 94 |
# File 'lib/paper_trail/model_config.rb', line 86 def on_touch @model_class.after_touch { |r| r.paper_trail.record_update( force: true, in_after_callback: true, is_touch: true ) } end |
#on_update ⇒ Object
Adds a callback that records a version after an “update” event.
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/paper_trail/model_config.rb', line 64 def on_update @model_class.before_save { |r| r.paper_trail. } @model_class.after_update { |r| if r.paper_trail.save_version? r.paper_trail.record_update( force: false, in_after_callback: true, is_touch: false ) end } @model_class.after_update { |r| r.paper_trail.clear_version_instance } return if @model_class.[:on].include?(:update) @model_class.[:on] << :update end |
#setup(options = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Set up ‘@model_class` for PaperTrail. Installs callbacks, associations, “class attributes”, instance methods, and more.
99 100 101 102 103 104 105 106 107 |
# File 'lib/paper_trail/model_config.rb', line 99 def setup( = {}) [:on] ||= %i[create update destroy touch] [:on] = Array([:on]) # Support single symbol @model_class.send :include, ::PaperTrail::Model::InstanceMethods () setup_associations() @model_class.after_rollback { paper_trail.clear_rolled_back_versions } [:on] end |
#version_class ⇒ Object
109 110 111 |
# File 'lib/paper_trail/model_config.rb', line 109 def version_class @_version_class ||= @model_class.version_class_name.constantize end |