Module: PaperTrail::VersionConcern

Extended by:
ActiveSupport::Concern
Included in:
Version
Defined in:
lib/paper_trail/version_concern.rb

Overview

Originally, PaperTrail did not provide this module, and all of this functionality was in PaperTrail::Version. That model still exists (and is used by most apps) but by moving the functionality to this module, people can include this concern instead of sub-classing the Version model.

Defined Under Namespace

Modules: ClassMethods

Instance Method Summary collapse

Instance Method Details

#changesetObject

Returns what changed in this version of the item. ‘ActiveModel::Dirty#changes`. returns nil if your versions table does not have an object_changes text column.



238
239
240
241
# File 'lib/paper_trail/version_concern.rb', line 238

def changeset
  return nil unless self.class.column_names.include? "object_changes"
  @changeset ||= load_changeset
end

#indexObject

Returns an integer representing the chronological position of the version among its siblings. The “create” event, for example, has an index of 0.



268
269
270
# File 'lib/paper_trail/version_concern.rb', line 268

def index
  @index ||= RecordHistory.new(sibling_versions, self.class).index(self)
end

#nextObject



255
256
257
# File 'lib/paper_trail/version_concern.rb', line 255

def next
  @next ||= sibling_versions.subsequent(self).first
end

#object_deserializedObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



202
203
204
205
206
207
208
# File 'lib/paper_trail/version_concern.rb', line 202

def object_deserialized
  if self.class.object_col_is_json?
    object
  else
    PaperTrail.serializer.load(object)
  end
end

#paper_trail_originatorObject

Returns who put the item into the state stored in this version.



244
245
246
# File 'lib/paper_trail/version_concern.rb', line 244

def paper_trail_originator
  @paper_trail_originator ||= previous.try(:whodunnit)
end

#previousObject



259
260
261
# File 'lib/paper_trail/version_concern.rb', line 259

def previous
  @previous ||= sibling_versions.preceding(self).first
end

#reify(options = {}) ⇒ Object

Restore the item from this version.

Options:

  • :mark_for_destruction

    • true - Mark the has_one/has_many associations that did not exist in the reified version for destruction, instead of removing them.

    • false - Default. Useful for persisting the reified version.

  • :dup

    • false - Default.

    • true - Always create a new object instance. Useful for comparing two versions of the same object.

  • :unversioned_attributes

    • :nil - Default. Attributes undefined in version record are set to nil in reified record.

    • :preserve - Attributes undefined in version record are not modified.



227
228
229
230
231
232
233
# File 'lib/paper_trail/version_concern.rb', line 227

def reify(options = {})
  unless self.class.column_names.include? "object"
    raise "reify can't be called without an object column"
  end
  return nil if object.nil?
  ::PaperTrail::Reifier.reify(self, options)
end

#terminatorObject Also known as: version_author

Returns who changed the item from the state it had in this version. This is an alias for whodunnit.



250
251
252
# File 'lib/paper_trail/version_concern.rb', line 250

def terminator
  @terminator ||= whodunnit
end